#!/bin/sh

# src : ftp://pkg-shadow.alioth.debian.org/pub/pkg-shadow/


CWD=`pwd`


APP="shadow"
VERSION="4.1.4.3"
ARCH="i486"
BUILD="70.1"

PKG=/tmp/$APP-$VERSION-$ARCH-$BUILD
TMP=$CWD/tmp

rm -rf $PKG $PKG.tgz $TMP
mkdir -p $PKG
mkdir -p $TMP


cd $TMP
rm -rf $APP-$VERSION
tar xvf $CWD/$APP-$VERSION.tar.gz
cd $APP-$VERSION

patch -p1 < $CWD/shadow-4.1.4-groups-fix-order.patch

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --mandir=/usr/man \
  --disable-shared \
  --with-libpam \
  --without-selinux \
  --build=$ARCH-zenwalk-linux

make || exit 1
make install DESTDIR=$PKG

mkdir -p $PKG/usr/doc/$APP-$VERSION
cp -a \
  COPYING Changelog README TODO doc \
  $PKG/usr/doc/$APP-$VERSION
chown -R root:root $PKG/usr/doc

cat $CWD/adduser > $PKG/usr/sbin/adduser
chmod 755 $PKG/usr/sbin/adduser

cat << "EOF" > $PKG/etc/default/useradd 
# useradd defaults file
HOME=/home
SHELL=/bin/bash
SKEL=/etc/skel
GROUP=users
EOF

cat $CWD/login.defs > $PKG/etc/login.defs

# Striptease
( 
  cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)
( cd $PKG/usr/man
  find . -name "*.?" | xargs gzip -9
)


# PAM policy files

cat << "EOF" > $PKG/etc/pam.d/login
auth		include		system-auth
account		required	pam_nologin.so
account		include		system-auth
password	include		system-auth
session		include		system-auth
session		required	pam_loginuid.so
EOF

cat << "EOF" > $PKG/etc/pam.d/su
auth		sufficient	pam_rootok.so
auth		include		system-auth
account		include		system-auth
password	include		system-auth
session		required	pam_unix.so
EOF

cat << "EOF" > $PKG/etc/pam.d/chsh
auth		sufficient	pam_rootok.so
auth       	include		system-auth
account    	include		system-auth
password   	required	pam_permit.so
session    	required	pam_deny.so
EOF
cp -f $PKG/etc/pam.d/chsh $PKG/etc/pam.d/chfn

# Install dir
mkdir -p $PKG/install
cat << "EOF" > $PKG/install/slack-desc
shadow: shadow (shadow password suite)
shadow:
shadow: This set of login related programs utilizes an alternate, non-readable
shadow: file to contain the actual encrypted passwords.  This is presumed to 
shadow: increase system security by increasing the difficulty with which 
shadow: system crackers obtain encrypted passwords.  
shadow: 
shadow: This package provides 'login', which is needed to log into the system.
shadow:
shadow:
shadow:
EOF


# Buildscript go home
mkdir -p $PKG/usr/src/$APP-$VERSION
cp $CWD/build-$APP.sh $PKG/usr/src/$APP-$VERSION
cp $CWD/*.patch $PKG/usr/src/$APP-$VERSION
chown -R root:root $PKG/usr/src
# Build the package:

cd $PKG
makepkg -l y -c y $PKG.txz

# Clean up the extra stuff:
rm -rf $TMP
rm -rf $PKG

